# Pythob BioArch
[![CircleCI](https://circleci.com/gh/TheBiggerGuy/pybioarch/tree/master.svg?style=svg)](https://circleci.com/gh/TheBiggerGuy/pybioarch/tree/master)
[![codecov](https://codecov.io/gh/TheBiggerGuy/pybioarch/branch/master/graph/badge.svg)](https://codecov.io/gh/TheBiggerGuy/pybioarch)

A Python bioarchaeology libary to help with modeling data in the archaeology/bioarchaeology field.
